# What's Changed

1. fix: 修复了代码执行器插件不能正确获得发送来文件的问题 ([#2970](https://github.com/AstrBotDevs/AstrBot/issues/2970))
2. fix: 修改的 DeepSeek 默认 modalities，避免默认勾选图像导致的报错。 ([#2963](https://github.com/AstrBotDevs/AstrBot/issues/2963))
3. fix: 事件钩子终止事件传播后不继续执行 ([#2989](https://github.com/AstrBotDevs/AstrBot/issues/2989))
4. fix: 启动了 TTS 但未配置 TTS 模型时，At 和 Reply 发送人无效
5. fix: 修复 session-management 中人格错误的显示为默认人格的问题 ([#3000](https://github.com/AstrBotDevs/AstrBot/issues/3000))
6. fix: 修复了删除对话时，聊天增强中的记录未被清除，导致新对话中仍然出现之前的聊天记录。 ([#3002](https://github.com/AstrBotDevs/AstrBot/issues/3002))
7. fix: 修复阿里云百炼平台 TTS 下接入 CosyVoice V2, Qwen TTS 生成报错的问题 ([#2964](https://github.com/AstrBotDevs/AstrBot/issues/2964))
8. perf: 优化 SQLite 参数配置，对话和会话管理增加输入防抖机制 ([#2969](https://github.com/AstrBotDevs/AstrBot/issues/2969))
9. feat: 在新对话中重用先前的对话人格设置 ([#3005](https://github.com/AstrBotDevs/AstrBot/issues/3005))
10. feat: 从 WebUI 更新后清除浏览器缓存 ([#2958](https://github.com/AstrBotDevs/AstrBot/issues/2958))
